## Deploying a ProxmoxVE Cluster
Proxmox Virtual Environment is an open source server virtualization management solution based on QEMU/KVM and LXC. You can manage virtual machines, containers, highly available clusters, storage and networks with an integrated, easy-to-use web interface or via CLI.

!!! note
    This document assumes you have a storage server that hosts both ISO files via CIFS/SMB share, and has the ability to set up an iSCSI LUN (VM & Container storage).  This document assumes that you are using a TrueNAS Core server to host both of these services.

### Create the first Node
You will need to download the [Proxmox VE 8.1 ISO Installer](https://www.proxmox.com/en/downloads) from the Official Proxmox Website.  Once it is downloaded, you can use [Balena Etcher](https://etcher.balena.io/#download-etcher) or [Rufus](https://rufus.ie/en/) to deploy Proxmox onto a server.

!!! warning
    If you are virtualizing Proxmox under a Hyper-V environment, you will need to follow the [Official Documentation](https://learn.microsoft.com/en-us/virtualization/hyper-v-on-windows/user-guide/enable-nested-virtualization) to ensure that nested virtualization is enabled.  An example is listed below:
    ```
    Set-VMProcessor -VMName <VMName> -ExposeVirtualizationExtensions $true # (1)
    Get-VMNetworkAdapter -VMName <VMName> | Set-VMNetworkAdapter -MacAddressSpoofing On # (2)
    ``` 

    1.  This tells Hyper-V to allow the GuestVM to behave as a hypervisor, nested under Hyper-V, allowing the virtualization functionality of the Hypervisor's CPU to be passed-through to the GuestVM.
    2.  This tells Hyper-V to allow your GuestVM to have multiple nested virtual machines with their own independant MAC addresses.  This is useful when using nested Virtual Machines, but is also a requirement when you set up a [Docker Network](https://docs.bunny-lab.io/Containers/Docker/Docker%20Networking/) leveraging MACVLAN technology.

### Networking
You will need to set a static IP address, in this case, it will be an address within the 20GbE network.  You will be prompted to enter these during the ProxmoxVE installation.  Be sure to set the hostname to something that matches the following FQDN: `proxmox-node-01.MOONGATE.local`.

| Hostname        | IP Address      | Subnet Mask         | Gateway | DNS Server | iSCSI Portal IP   |
| --------------- | --------------- | ------------------- | ------- | ---------- | ----------------- |
| proxmox-node-01 | 192.168.101.200 | 255.255.255.0 (/24) | None    | 1.1.1.1    | 192.168.101.100   |
| proxmox-node-01 | 192.168.103.200 | 255.255.255.0 (/24) | None    | 1.1.1.1    | 192.168.103.100   |
| proxmox-node-02 | 192.168.102.200 | 255.255.255.0 (/24) | None    | 1.1.1.1    | 192.168.102.100   |
| proxmox-node-02 | 192.168.104.200 | 255.255.255.0 (/24) | None    | 1.1.1.1    | 192.168.104.100   |

### iSCSI Initator Configuration
You will need to add the iSCSI initiator from the proxmox node to the allowed initiator list in TrueNAS Core under "**Sharing > Block Shares (iSCSI) > Initiators Groups**"

In this instance, we will reference Group ID: `2`.  We need to add the iniator to the "**Allowed Initiators (IQN)**" section. This also includes the following networks that are allowed to connect to the iSCSI portal:

- 192.168.101.0/24
- 192.168.102.0/24
- 192.168.103.0/24
- 192.168.104.0/24

To get the iSCSI Initiator IQN of the current Proxmox node, you need to navigate to the Proxmox server's webUI, typically located at `https://<IP>:8006` then log in with username `root` and whatever you set the password to during initial setup when the ISO image was mounted earlier.

- On the left-hand side, click on the name of the server node (e.g. `proxmox-node-01` or `proxmox-node-02`)
- Click on "**Shell**" to open a CLI to the server
- Run the following command to get the iSCSI Initiator (IQN) name to give to TrueNAS Core for the previously-mentioned steps:
``` sh
cat /etc/iscsi/initiatorname.iscsi | grep "InitiatorName=" | sed 's/InitiatorName=//'
```

!!! example
    Example output of this command will look like `iqn.1993-08.org.debian:01:b16b0ff1778`.